from marshmallow import Schema, fields, post_load, validates, ValidationError

class EquipmentSchema(Schema):
    equipment_name = fields.String(required=True)
    serial_number = fields.String(required=True)
    status = fields.String(required=True)
    site_id = fields.Integer(required=True)
    device_name = fields.String(required=False)
    device_id = fields.String(required=False)
    description = fields.String(required=False)

    @validates("equipment_name")
    def validate_equipment_name(self, value):
        if not value.strip():
            raise ValidationError("The Equipment Name field is required.")

    @validates("serial_number")
    def validate_serial_number(self, value):
        if not value.strip():
            raise ValidationError("The Serial Number field is required.")

    @post_load
    def make_equipment(self, data, **kwargs):
        return data

equipment_schema = EquipmentSchema()
equipments_schema = EquipmentSchema(many=True)
